<!--

steps to build:

 - increment build number
 - run `python3 -m pip wheel ./`

-->

# asynctasklist

<!-- [![PyPI](https://img.shields.io/pypi/v/asynctasklist.svg)](https://pypi.org/project/asynctasklist/)
[![Tests](https://github.com/moojor224/asynctasklist/actions/workflows/test.yml/badge.svg)](https://github.com/moojor224/asynctasklist/actions/workflows/test.yml)
[![Changelog](https://img.shields.io/github/v/release/moojor224/asynctasklist?include_prereleases&label=changelog)](https://github.com/moojor224/asynctasklist/releases)
[![License](https://img.shields.io/badge/license-Apache%202.0-blue.svg)](https://github.com/moojor224/asynctasklist/blob/main/LICENSE) -->

a simple asynctasklist library for running tasks

## Installation

<!-- Install this library using `pip`:
```bash
pip install asynctasklist
``` -->


## Usage

I'll add this later

## Development

To contribute to this library, clone the ropository, make changes, then submit a pull request
<!-- ```bash
cd asynctasklist
python -m venv venv
source venv/bin/activate
``` -->
Now install the dependencies and test dependencies:
```bash
pip install -e '.[test]'
```
To run the tests:
```bash
pytest
```
